@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Component/Throttle.pm 4037 2007-10-25T14:20:48.994833Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Component/Throttle.pm 9352 2007-11-21T02:13:31.513580Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 
@@ -8,7 +8,13 @@ use warnings;
 use base qw(Gungho::Component);
 
 sub feature_name { 'Throttle' }
-sub throttle { 1 }
+
+sub throttle
+{
+    my $c = shift;
+    $c->log->debug( $_[0]->url . " NOT throttled" );
+    return 1;
+}
 
 sub send_request
 {
@@ -17,8 +23,9 @@ sub send_request
     if (! $request->notes('original_host') && ! $c->throttle($request)) {
         $c->log->debug("Request " . $request->url . " (" . $request->id . ") was throttled");
         $c->provider->pushback_request($c, $request);
+        return 0;
     } else {
-        $c->next::method($request);
+        return $c->next::method($request);
     }
 }
 
@@ -88,6 +95,11 @@ the throttler argument in the configuration:
       max_items: 100
       interval: 3600
 
+Starting from 0.09003, you can stack throttlers. For example, you can throttle
+by Throttle::Simple first, and if Throttle::Simple allowed the request to
+go, then you can  throttle with Throttle::Domain as well to make sure that
+the same host doesn't get beaten up.
+
 =head1 METHODS
 
 =head2 feature_name
